"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMetaplexTokenMetadata = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const spl_utils_1 = require("@strata-foundation/spl-utils");
const react_async_hook_1 = require("react-async-hook");
const _1 = require(".");
const useAccount_1 = require("./useAccount");
const useMint_1 = require("./useMint");
const useTwWrappedSolMint_1 = require("./useTwWrappedSolMint");
const parser = (key, acct) => acct && new mpl_token_metadata_1.Metadata(key, acct).data;
const solMetadata = new mpl_token_metadata_1.MetadataData({
    updateAuthority: "",
    mint: spl_token_1.NATIVE_MINT.toBase58(),
    data: new mpl_token_metadata_1.DataV2({
        name: "Solana",
        symbol: "SOL",
        uri: "https://strata-token-metadata.s3.us-east-2.amazonaws.com/sol.json",
        creators: null,
        sellerFeeBasisPoints: 0,
        collection: null,
        uses: null
    }),
    primarySaleHappened: false,
    isMutable: false,
    editionNonce: null,
});
/**
 * Get the token account and all metaplex metadata around the token
 *
 * @param token
 * @returns
 */
function useMetaplexTokenMetadata(token) {
    const { result: metadataAccountKey, loading, error, } = (0, react_async_hook_1.useAsync)((token) => __awaiter(this, void 0, void 0, function* () { return token ? mpl_token_metadata_1.Metadata.getPDA(token) : undefined; }), [token === null || token === void 0 ? void 0 : token.toBase58()]);
    let { info: metadata, loading: accountLoading } = (0, useAccount_1.useAccount)(metadataAccountKey, parser);
    const wrappedSolMint = (0, useTwWrappedSolMint_1.useTwWrappedSolMint)();
    const isSol = (token === null || token === void 0 ? void 0 : token.equals(spl_token_1.NATIVE_MINT)) ||
        (wrappedSolMint && (token === null || token === void 0 ? void 0 : token.equals(wrappedSolMint)));
    if (isSol) {
        metadata = solMetadata;
    }
    const { tokenMetadataSdk: splTokenMetadataSdk } = (0, _1.useStrataSdks)();
    const getEditionInfo = splTokenMetadataSdk
        ? splTokenMetadataSdk.getEditionInfo
        : () => Promise.resolve({});
    const { result: editionInfo } = (0, react_async_hook_1.useAsync)((metadata) => __awaiter(this, void 0, void 0, function* () { return (yield getEditionInfo(metadata)) || []; }), [metadata]);
    const { result: data, loading: dataLoading, error: dataError, } = (0, react_async_hook_1.useAsync)(spl_utils_1.SplTokenMetadata.getArweaveMetadata, [metadata === null || metadata === void 0 ? void 0 : metadata.data.uri]);
    const { result: image, loading: imageLoading, error: imageError, } = (0, react_async_hook_1.useAsync)(spl_utils_1.SplTokenMetadata.getImage, [metadata === null || metadata === void 0 ? void 0 : metadata.data.uri]);
    const mint = (0, useMint_1.useMint)(token);
    return Object.assign({ loading: Boolean(token && (loading || accountLoading || dataLoading || imageLoading)), error: error || dataError || imageError, mint,
        metadata, metadataKey: metadataAccountKey, data, image: image, description: data === null || data === void 0 ? void 0 : data.description }, editionInfo);
}
exports.useMetaplexTokenMetadata = useMetaplexTokenMetadata;
//# sourceMappingURL=useMetaplexMetadata.js.map